==> flutter_conscent_plugin-0.3.6.tar.gz: lib/web_view_login.dart <==
import 'dart:io' show Platform;


import 'package:flutter/material.dart';
import 'package:flutter_conscent_plugin/shared_pref.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/AutoLoginResponse.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challenge_post.dart';

class WebViewLogin extends StatefulWidget {
  final String token;
  final String? phone;
  final String? email;
  const WebViewLogin({Key? key, required this.token, required this.phone, required this.email})
      : super(key: key);

  @override
  State<WebViewLogin> createState() => _WebViewLoginState();
}

class _WebViewLoginState extends State<WebViewLogin> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;

  @override
  void initState() {
    if (mounted) {
      createAndGetLogInChallenge();
    }
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  Future<void> createAndGetLogInChallenge() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    var response;
    if(loginId == null){
      response = await http.post(Uri.parse('${ApiMode.BASE_URL}api/v1/login-challenge'), body: {
        "loginChallengeId": '${DateTime.now().millisecondsSinceEpoch.toString()}${Uuid().v4()}',
        "redirectTo": ""
      });

      if (response.statusCode == 201) {
        var responseString = response.body;
        String loginChallengeId =
            loginChallengepostFromJson(responseString).loginChallengeId;
        final prefs = await SharedPreferences.getInstance();
        await prefs.setString('loginID', loginChallengeId);
        loginId =  loginChallengeId;
        setState(() {});
      } else {
        ConscentMethods().onPluginError(response.body);
        throw Exception('Failed to create album.');
      }
    }else{

      setState(() {});
    }




  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'AUTOLOGIN',
        onMessageReceived: (JavascriptMessage message) async {

          AutoLoginResponse autoLoginResponse = autoLoginResponseFromJson(message.message);
          print("AUTOLOGIN autoLoginResponse ${autoLoginResponse.toJson()}");

          final prefs = await SharedPreferences.getInstance();


          if(autoLoginResponse.status == true){
            String? sessionId = autoLoginResponse.sessionId;
            prefs.setString('sessionId', sessionId!);
            SharedPref().setUserId(autoLoginResponse.userId);
            Navigator.pop(context,{autoLoginResponse.userId, autoLoginResponse.status});
          }else{
            if(loginId != null){
              Navigator.pop(context,{autoLoginResponse.message, autoLoginResponse.status});
            }

          }

        });
  }



  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {


    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;
    print("widget.userAgent ${userAgent?.replaceAll("; wv", "")}");

    return Container(
        height: 100,
        width: 200,
        child: loginId != null
            ?  WebView(
        initialUrl: "${ApiMode.SERVICE_BASE_URL}/auto-login-user?id=${widget.token}&clientId=${ConscentInitializer.mClientId}&phone=${widget.phone}&email=${widget.email}&loginChallengeId=$loginId",
        javascriptMode: JavascriptMode.unrestricted,
        userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
        onProgress: (int progress) async {
          <JavascriptChannel>{_javascriptChannel()};
        },
        onWebViewCreated: (controller) {

        },
        navigationDelegate: (NavigationRequest request) {


          return NavigationDecision.navigate;
        },
        onPageStarted: (String url) {
          print(url);
        },
        onPageFinished: (String url) {

        },
        javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
      )  : Center(child: CircularProgressIndicator()),
    );

  }
}

==> flutter_conscent_plugin-0.3.8.tar.gz: lib/web_view_login.dart <==
import 'dart:io' show Platform;


import 'package:flutter/material.dart';
import 'package:flutter_conscent_plugin/shared_pref.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/auto_login_response.dart';
import 'datamodel/login_challenge_post.dart';

class WebViewLogin extends StatefulWidget {
  final String token;
  final String? phone;
  final String? email;
  const WebViewLogin({Key? key, required this.token, required this.phone, required this.email})
      : super(key: key);

  @override
  State<WebViewLogin> createState() => _WebViewLoginState();
}

class _WebViewLoginState extends State<WebViewLogin> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;

  @override
  void initState() {
    if (mounted) {
      _createAndGetLogInChallenge();
    }
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  Future<void> _createAndGetLogInChallenge() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    var response;
    if(loginId == null){
      response = await http.post(Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge'), body: {
        "loginChallengeId": '${DateTime.now().millisecondsSinceEpoch.toString()}${Uuid().v4()}',
        "redirectTo": ""
      });

      if (response.statusCode == 201) {
        var responseString = response.body;
        String loginChallengeId =
            loginChallengepostFromJson(responseString).loginChallengeId;
        final prefs = await SharedPreferences.getInstance();
        await prefs.setString('loginID', loginChallengeId);
        loginId =  loginChallengeId;
        setState(() {});
      } else {
        ConscentMethods().onPluginError(response.body);
        throw Exception('Failed to create album.');
      }
    }else{

      setState(() {});
    }




  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'AUTOLOGIN',
        onMessageReceived: (JavascriptMessage message) async {
          print("AUTOLOGIN autoLoginResponse ${message.message}");
          AutoLoginResponse autoLoginResponse = autoLoginResponseFromJson(message.message);
          print("AUTOLOGIN autoLoginResponse ${autoLoginResponse.toJson()}");

          final prefs = await SharedPreferences.getInstance();


          if(autoLoginResponse.status == true){
            Constants.logIn = true;
            String? sessionId = autoLoginResponse.sessionId;
            prefs.setString('sessionId', sessionId!);
            SharedPref().setUserId(autoLoginResponse.userId);
            Navigator.pop(context,{autoLoginResponse.userId, autoLoginResponse.status});
          }else{
            if(loginId != null){
              Navigator.pop(context,{autoLoginResponse.message, autoLoginResponse.status});
            }

          }

        });
  }


  @override
  Widget build(BuildContext context) {


    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;

    print("widget.userAgent ${userAgent?.replaceAll("; wv", "")}");

    return SizedBox(
        height: 100,
        width: 200,
        child: loginId != null
            ?  WebView(
        initialUrl: "${APIMode.SERVICE_BASE_URL}/auto-login-user?id=${widget.token}&clientId=${ConscentInitializer.mClientId}&phone=${widget.phone}&email=${widget.email}&loginChallengeId=$loginId",
        javascriptMode: JavascriptMode.unrestricted,
        userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
        onProgress: (int progress) async {
          <JavascriptChannel>{_javascriptChannel()};
        },
        onWebViewCreated: (controller) {

        },
        navigationDelegate: (NavigationRequest request) {


          return NavigationDecision.navigate;
        },
        onPageStarted: (String url) {
          print(url);
        },
        onPageFinished: (String url) {

        },
        javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
      )  : const Center(child: CircularProgressIndicator()),
    );

  }
}
